RsaKeyBits

Trait RsaKeyBits 

pub trait RsaKeyBits:
    Sized
    + Copy
    + Clone
    + Default
    + Display
    + Debug
    + Sealed {
    const BITS: usize;
}
The bit length of an RSA key.

The RsaPrivKey and RsaPubKey types take a B: RsaKeyBits type parameter indicating the key’s length in bits.

We only support bit lengths of 2048 or greater, as smaller bit lengths are considered insecure. If 2048 is considered insecure at some point in the future, then we will remove support for it, which will be a breaking change.

Required Associated Constants

const BITS: usize

The number of bits.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors